#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 21/1/2009
#
#package			: alsa-utils
#homepage			: http://www.alsa-project.org/main/index.php/Main_Page
#source location	: ftp://ftp.alsa-project.org/pub/utils/alsa-utils-1.0.19.tar.bz2
#dependency         : 

softname='alsa-utils'
softversion='1.0.19'
packageversion='54.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=ftp://ftp.alsa-project.org/pub/utils/$softname-$softversion.tar.bz2

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
alsa-utils: alsa-utils (Advanced Linux Sound Architecture utilities)
alsa-utils: 
alsa-utils: The Advanced Linux Sound Architecture (ALSA) provides audio and MID
alsa-utils: functionality to the Linux operating system.  This package contains
alsa-utils: command line audio utilities for use with ALSA:
alsa-utils: alsactl        (manage soundcard settings)
alsa-utils: arecord/aplay  (capture and play audio)
alsa-utils: amixer         (adjust mixer settings from the command line)
alsa-utils: alsamixer      (an ncurses-based console mixer)
alsa-utils: 
alsa-utils: 
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xjvf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
patch -Np1 -i $buildir/alsa-utils.alsaconf.diff	

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

#
# "faire" le package package
#
make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
make install DESTDIR=$dest

#
# fichier pour charger alsa
#
mkdir -p $dest/etc/rc.d
cp $buildir/rc.alsa $dest/etc/rc.d/rc.alsa
chmod 755 $dest/etc/rc.d/rc.alsa
   
#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ChangeLog COPYING INSTALL README TODO \
      seq/aconnect/README.aconnect \
      seq/aseqnet/README.aseqnet \
      $dest/usr/doc/$softname-$softversion
	cp -a alsamixer/README $dest/usr/doc/$softname-$softversion/README.alsamixer
	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp rc.alsa $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "alsa-lib,ncurses" > $package.dep

#
# src file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/ap/alsa-utils/source/build-alsa-utils.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/ap/alsa-utils/source/rc.alsa >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
